@@ -2,10 +2,10 @@ import itertools
 import typing
 import random
 import string
-from typing import TypeVar, Callable, Generic, Iterable, Any
 from functools import reduce
+from typing import TypeVar, Callable, Generic, Iterable, Any
 
-from toolz.itertoolz import cons
+from toolz.itertoolz import cons, groupby
 
 from amino import maybe, boolean
 from amino.logging import log
@@ -29,10 +29,14 @@ class ListMeta(ImplicitsMeta):
         else:
             return super().__instancecheck__(instance)
 
-    def __subclasscheck__(self, subclass):
-        if subclass is list:
-            return False
-        return super().__subclasscheck__(subclass)
+    # def __subclasscheck__(self, subclass):
+    #     if subclass is list:
+    #         return False
+    #     return super().__subclasscheck__(subclass)
+
+
+def _rand_str(chars, num: int=10):
+    return ''.join(random.choice(chars) for i in range(num))
 
 
 class List(typing.List[A], Generic[A], Implicits, implicits=True,
@@ -56,7 +60,12 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
     @staticmethod
     def random_string(num: int=10):
         chars = string.ascii_letters + string.digits
-        return ''.join(random.choice(chars) for i in range(num))
+        return _rand_str(chars, num)
+
+    @staticmethod
+    def random_alpha(num: int=10):
+        chars = string.ascii_letters
+        return _rand_str(chars, num)
 
     @staticmethod
     def gen(num: int, f: Callable[[], A]):
@@ -106,6 +115,10 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
 
     empty = is_empty
 
+    @property
+    def nonempty(self) -> boolean.Boolean:
+        return not self.empty
+
     @property
     def length(self):
         return len(self)
@@ -179,21 +192,25 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
     def reversed(self):
         return List.wrap(reversed(self))
 
-    def mk_string(self, sep=''):
+    def mk_string(self, sep: str='') -> str:
         return sep.join(self / str)
 
     @property
-    def join_lines(self):
+    def join_lines(self) -> str:
         return self.mk_string('\n')
 
     @property
-    def join_comma(self):
+    def join_comma(self) -> str:
         return self.mk_string(', ')
 
     @property
-    def join_tokens(self):
+    def join_tokens(self) -> str:
         return self.mk_string(' ')
 
+    @property
+    def join_dot(self) -> str:
+        return self.mk_string('.')
+
     def cons(self, item):
         return List.wrap(cons(item, self))
 
@@ -207,18 +224,25 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
     def transpose(self):
         return List.wrap(map(List.wrap, zip(*self)))
 
-    def drop(self, n: int):
+    def drop(self, n: int) -> 'List[A]':
         return self[n:]
 
+    def take(self, n: int):
+        return self[:n]
+
     def drop_while(self, pred: Callable[[A], bool]):
         index = self.index_where(lambda a: not pred(a))
         return index / (lambda a: self[a:]) | self
 
+    def drop_right(self, n: int) -> 'List[A]':
+        return self.take(self.length - n)
+
     def remove_all(self, els: 'List[A]') -> 'List[A]':
         return self.filter_not(els.contains)
 
     def __repr__(self):
-        return 'List({})'.format(', '.join(map(repr, self)))
+        return '{}({})'.format(self.__class__.__name__,
+                               ', '.join(map(repr, self)))
 
     def __str__(self):
         return '[{}]'.format(', '.join(map(safe_string, self)))
@@ -242,4 +266,26 @@ class List(typing.List[A], Generic[A], Implicits, implicits=True,
     def __mul__(self, other):
         return List.wrap(super().__mul__(other))
 
+    def group_by(self, f):
+        from amino import Map
+        return Map(groupby(f, self)).valmap(List.wrap)
+
+
+class Lists:
+
+    wrap = List.wrap
+    range = List.range
+    random_string = List.random_string
+    random_alpha = List.random_alpha
+    gen = List.gen
+    lines = List.lines
+
+    @staticmethod
+    def split(data: str, splitter: str, maxsplit: int=-1) -> List[str]:
+        return List.wrap(data.split(splitter, maxsplit))
+
+    @staticmethod
+    def rsplit(data: str, splitter: str, maxsplit: int=-1) -> List[str]:
+        return List.wrap(data.rsplit(splitter, maxsplit))
+
 __all__ = ('List',)
