@@ -2,7 +2,7 @@ import re
 from functools import singledispatch  # type: ignore
 
 
-def snake_case(name):
+def snake_case(name: str) -> str:
     s1 = re.sub('(.)([A-Z][a-z]+)', r'\1_\2', name)
     return re.sub('([a-z0-9])([A-Z])', r'\1_\2', s1).lower()
 
